@@ -222,11 +222,9 @@ class Agent(BaseAgent):
 
         memory_attributes = [
             "memory",
-            "memory_config",
             "_short_term_memory",
             "_long_term_memory",
             "_entity_memory",
-            "_user_memory",
             "_external_memory",
         ]
 
@@ -316,11 +314,9 @@ class Agent(BaseAgent):
 
             start_time = time.time()
             contextual_memory = ContextualMemory(
-                self.crew.memory_config,
                 self.crew._short_term_memory,
                 self.crew._long_term_memory,
                 self.crew._entity_memory,
-                self.crew._user_memory,
                 self.crew._external_memory,
             )
             memory = contextual_memory.build_context_for_task(task, context)
