@@ -47,7 +47,6 @@ from crewai.memory.entity.entity_memory import EntityMemory
 from crewai.memory.external.external_memory import ExternalMemory
 from crewai.memory.long_term.long_term_memory import LongTermMemory
 from crewai.memory.short_term.short_term_memory import ShortTermMemory
-from crewai.memory.user.user_memory import UserMemory
 from crewai.process import Process
 from crewai.security import Fingerprint, SecurityConfig
 from crewai.task import Task
@@ -73,6 +72,12 @@ from crewai.utilities.events.crew_events import (
 )
 from crewai.utilities.events.crewai_event_bus import crewai_event_bus
 from crewai.utilities.events.event_listener import EventListener
+from crewai.utilities.events.listeners.tracing.trace_listener import (
+    TraceCollectionListener,
+)
+
+
+from crewai.utilities.events.listeners.tracing.utils import is_tracing_enabled
 from crewai.utilities.formatter import (
     aggregate_raw_outputs_from_task_outputs,
     aggregate_raw_outputs_from_tasks,
@@ -95,7 +100,6 @@ class Crew(FlowTrackable, BaseModel):
         manager_llm: The language model that will run manager agent.
         manager_agent: Custom agent that will be used as manager.
         memory: Whether the crew should use memory to store memories of it's execution.
-        memory_config: Configuration for the memory to be used for the crew.
         cache: Whether the crew should use a cache to store the results of the tools execution.
         function_calling_llm: The language model that will run the tool calling for all the agents.
         process: The process flow that the crew will follow (e.g., sequential, hierarchical).
@@ -121,7 +125,6 @@ class Crew(FlowTrackable, BaseModel):
     _short_term_memory: Optional[InstanceOf[ShortTermMemory]] = PrivateAttr()
     _long_term_memory: Optional[InstanceOf[LongTermMemory]] = PrivateAttr()
     _entity_memory: Optional[InstanceOf[EntityMemory]] = PrivateAttr()
-    _user_memory: Optional[InstanceOf[UserMemory]] = PrivateAttr()
     _external_memory: Optional[InstanceOf[ExternalMemory]] = PrivateAttr()
     _train: Optional[bool] = PrivateAttr(default=False)
     _train_iteration: Optional[int] = PrivateAttr()
@@ -133,7 +136,7 @@ class Crew(FlowTrackable, BaseModel):
         default_factory=TaskOutputStorageHandler
     )
 
-    name: Optional[str] = Field(default=None)
+    name: Optional[str] = Field(default="crew")
     cache: bool = Field(default=True)
     tasks: List[Task] = Field(default_factory=list)
     agents: List[BaseAgent] = Field(default_factory=list)
@@ -143,10 +146,6 @@ class Crew(FlowTrackable, BaseModel):
         default=False,
         description="Whether the crew should use memory to store memories of it's execution",
     )
-    memory_config: Optional[Dict[str, Any]] = Field(
-        default=None,
-        description="Configuration for the memory to be used for the crew.",
-    )
     short_term_memory: Optional[InstanceOf[ShortTermMemory]] = Field(
         default=None,
         description="An Instance of the ShortTermMemory to be used by the Crew",
@@ -159,10 +158,6 @@ class Crew(FlowTrackable, BaseModel):
         default=None,
         description="An Instance of the EntityMemory to be used by the Crew",
     )
-    user_memory: Optional[InstanceOf[UserMemory]] = Field(
-        default=None,
-        description="DEPRECATED: Will be removed in version 0.156.0 or on 2025-08-04, whichever comes first. Use external_memory instead.",
-    )
     external_memory: Optional[InstanceOf[ExternalMemory]] = Field(
         default=None,
         description="An Instance of the ExternalMemory to be used by the Crew",
@@ -249,6 +244,14 @@ class Crew(FlowTrackable, BaseModel):
         default_factory=SecurityConfig,
         description="Security configuration for the crew, including fingerprinting.",
     )
+    token_usage: Optional[UsageMetrics] = Field(
+        default=None,
+        description="Metrics for the LLM usage during all tasks execution.",
+    )
+    tracing: Optional[bool] = Field(
+        default=False,
+        description="Whether to enable tracing for the crew.",
+    )
 
     @field_validator("id", mode="before")
     @classmethod
@@ -280,6 +283,9 @@ class Crew(FlowTrackable, BaseModel):
 
         self._cache_handler = CacheHandler()
         event_listener = EventListener()
+        if is_tracing_enabled() or self.tracing:
+            trace_listener = TraceCollectionListener(tracing=self.tracing)
+            trace_listener.setup_listeners(crewai_event_bus)
         event_listener.verbose = self.verbose
         event_listener.formatter.verbose = self.verbose
         self._logger = Logger(verbose=self.verbose)
@@ -291,20 +297,6 @@ class Crew(FlowTrackable, BaseModel):
 
         return self
 
-    def _initialize_user_memory(self):
-        if (
-            self.memory_config
-            and "user_memory" in self.memory_config
-            and self.memory_config.get("provider") == "mem0"
-        ):  # Check for user_memory in config
-            user_memory_config = self.memory_config["user_memory"]
-            if isinstance(
-                user_memory_config, dict
-            ):  # Check if it's a configuration dict
-                self._user_memory = UserMemory(crew=self)
-            else:
-                raise TypeError("user_memory must be a configuration dictionary")
-
     def _initialize_default_memories(self):
         self._long_term_memory = self._long_term_memory or LongTermMemory()
         self._short_term_memory = self._short_term_memory or ShortTermMemory(
@@ -327,12 +319,8 @@ class Crew(FlowTrackable, BaseModel):
         self._short_term_memory = self.short_term_memory
         self._entity_memory = self.entity_memory
 
-        # UserMemory will be removed in version 0.156.0 or on 2025-08-04, whichever comes first
-        self._user_memory = None
-
         if self.memory:
             self._initialize_default_memories()
-            self._initialize_user_memory()
 
         return self
 
@@ -575,7 +563,7 @@ class Crew(FlowTrackable, BaseModel):
             crewai_event_bus.emit(
                 self,
                 CrewTrainStartedEvent(
-                    crew_name=self.name or "crew",
+                    crew_name=self.name,
                     n_iterations=n_iterations,
                     filename=filename,
                     inputs=inputs,
@@ -602,7 +590,7 @@ class Crew(FlowTrackable, BaseModel):
             crewai_event_bus.emit(
                 self,
                 CrewTrainCompletedEvent(
-                    crew_name=self.name or "crew",
+                    crew_name=self.name,
                     n_iterations=n_iterations,
                     filename=filename,
                 ),
@@ -610,7 +598,7 @@ class Crew(FlowTrackable, BaseModel):
         except Exception as e:
             crewai_event_bus.emit(
                 self,
-                CrewTrainFailedEvent(error=str(e), crew_name=self.name or "crew"),
+                CrewTrainFailedEvent(error=str(e), crew_name=self.name),
             )
             self._logger.log("error", f"Training failed: {e}", color="red")
             CrewTrainingHandler(TRAINING_DATA_FILE).clear()
@@ -634,7 +622,7 @@ class Crew(FlowTrackable, BaseModel):
 
             crewai_event_bus.emit(
                 self,
-                CrewKickoffStartedEvent(crew_name=self.name or "crew", inputs=inputs),
+                CrewKickoffStartedEvent(crew_name=self.name, inputs=inputs),
             )
 
             # Starts the crew to work on its assigned tasks.
@@ -683,7 +671,7 @@ class Crew(FlowTrackable, BaseModel):
         except Exception as e:
             crewai_event_bus.emit(
                 self,
-                CrewKickoffFailedEvent(error=str(e), crew_name=self.name or "crew"),
+                CrewKickoffFailedEvent(error=str(e), crew_name=self.name),
             )
             raise
         finally:
@@ -1073,11 +1061,13 @@ class Crew(FlowTrackable, BaseModel):
 
         final_string_output = final_task_output.raw
         self._finish_execution(final_string_output)
-        token_usage = self.calculate_usage_metrics()
+        self.token_usage = self.calculate_usage_metrics()
         crewai_event_bus.emit(
             self,
             CrewKickoffCompletedEvent(
-                crew_name=self.name or "crew", output=final_task_output
+                crew_name=self.name,
+                output=final_task_output,
+                total_tokens=self.token_usage.total_tokens,
             ),
         )
         return CrewOutput(
@@ -1085,7 +1075,7 @@ class Crew(FlowTrackable, BaseModel):
             pydantic=final_task_output.pydantic,
             json_dict=final_task_output.json_dict,
             tasks_output=task_outputs,
-            token_usage=token_usage,
+            token_usage=self.token_usage,
         )
 
     def _process_async_tasks(
@@ -1254,9 +1244,6 @@ class Crew(FlowTrackable, BaseModel):
             copied_data["entity_memory"] = self.entity_memory.model_copy(deep=True)
         if self.external_memory:
             copied_data["external_memory"] = self.external_memory.model_copy(deep=True)
-        if self.user_memory:
-            # DEPRECATED: UserMemory will be removed in version 0.156.0 or on 2025-08-04
-            copied_data["user_memory"] = self.user_memory.model_copy(deep=True)
 
         copied_data.pop("agents", None)
         copied_data.pop("tasks", None)
@@ -1325,7 +1312,7 @@ class Crew(FlowTrackable, BaseModel):
             crewai_event_bus.emit(
                 self,
                 CrewTestStartedEvent(
-                    crew_name=self.name or "crew",
+                    crew_name=self.name,
                     n_iterations=n_iterations,
                     eval_llm=llm_instance,
                     inputs=inputs,
@@ -1344,13 +1331,13 @@ class Crew(FlowTrackable, BaseModel):
             crewai_event_bus.emit(
                 self,
                 CrewTestCompletedEvent(
-                    crew_name=self.name or "crew",
+                    crew_name=self.name,
                 ),
             )
         except Exception as e:
             crewai_event_bus.emit(
                 self,
-                CrewTestFailedEvent(error=str(e), crew_name=self.name or "crew"),
+                CrewTestFailedEvent(error=str(e), crew_name=self.name),
             )
             raise
 
