@@ -1,11 +1,9 @@
 from .entity.entity_memory import EntityMemory
 from .long_term.long_term_memory import LongTermMemory
 from .short_term.short_term_memory import ShortTermMemory
-from .user.user_memory import UserMemory
 from .external.external_memory import ExternalMemory
 
 __all__ = [
-    "UserMemory",
     "EntityMemory",
     "LongTermMemory",
     "ShortTermMemory",
