@@ -282,9 +282,6 @@ def test_gemini_models(model):
 @pytest.mark.parametrize(
     "model",
     [
-        "gemini/gemma-3-1b-it",
-        "gemini/gemma-3-4b-it",
-        "gemini/gemma-3-12b-it",
         "gemini/gemma-3-27b-it",
     ],
 )
@@ -377,6 +374,7 @@ def get_weather_tool_schema():
         },
     }
 
+
 def test_context_window_exceeded_error_handling():
     """Test that litellm.ContextWindowExceededError is converted to LLMContextLengthExceededException."""
     from litellm.exceptions import ContextWindowExceededError
@@ -392,7 +390,7 @@ def test_context_window_exceeded_error_handling():
         mock_completion.side_effect = ContextWindowExceededError(
             "This model's maximum context length is 8192 tokens. However, your messages resulted in 10000 tokens.",
             model="gpt-4",
-            llm_provider="openai"
+            llm_provider="openai",
         )
 
         with pytest.raises(LLMContextLengthExceededException) as excinfo:
@@ -407,7 +405,7 @@ def test_context_window_exceeded_error_handling():
         mock_completion.side_effect = ContextWindowExceededError(
             "This model's maximum context length is 8192 tokens. However, your messages resulted in 10000 tokens.",
             model="gpt-4",
-            llm_provider="openai"
+            llm_provider="openai",
         )
 
         with pytest.raises(LLMContextLengthExceededException) as excinfo:
@@ -598,6 +596,7 @@ def test_handle_streaming_tool_calls(get_weather_tool_schema, mock_emit):
         expected_final_chunk_result=expected_final_chunk_result,
     )
 
+
 @pytest.mark.vcr(filter_headers=["authorization"])
 def test_handle_streaming_tool_calls_with_error(get_weather_tool_schema, mock_emit):
     def get_weather_error(location):
@@ -609,9 +608,7 @@ def test_handle_streaming_tool_calls_with_error(get_weather_tool_schema, mock_em
             {"role": "user", "content": "What is the weather in New York?"},
         ],
         tools=[get_weather_tool_schema],
-        available_functions={
-            "get_weather": get_weather_error
-        },
+        available_functions={"get_weather": get_weather_error},
     )
     assert response == ""
     expected_final_chunk_result = '{"location":"New York, NY"}'
@@ -676,8 +673,11 @@ def test_llm_call_when_stop_is_unsupported(caplog):
     assert isinstance(result, str)
     assert "Paris" in result
 
+
 @pytest.mark.vcr(filter_headers=["authorization"])
-def test_llm_call_when_stop_is_unsupported_when_additional_drop_params_is_provided(caplog):
+def test_llm_call_when_stop_is_unsupported_when_additional_drop_params_is_provided(
+    caplog,
+):
     llm = LLM(model="o1-mini", stop=["stop"], additional_drop_params=["another_param"])
     with caplog.at_level(logging.INFO):
         result = llm.call("What is the capital of France?")
@@ -690,6 +690,7 @@ def test_llm_call_when_stop_is_unsupported_when_additional_drop_params_is_provid
 def ollama_llm():
     return LLM(model="ollama/llama3.2:3b")
 
+
 def test_ollama_appends_dummy_user_message_when_last_is_assistant(ollama_llm):
     original_messages = [
         {"role": "user", "content": "Hi there"},
